# krosstrading
[![Build Status](https://circleci.com/gh/nnnlife/krosstrading.svg?style=shield)](https://circleci.com/gh/nnnlife/krosstrading)
[![codecov](https://codecov.io/gh/nnnlife/krosstrading/branch/main/graph/badge.svg)](https://codecov.io/gh/nnnlife/krosstrading)
